> ## 🛠 Status: In Development
> Ihsan is currently in development. So we encourage you to use it and give us your feedback, but there are things that haven't been finalized yet and you can expect some changes.
>
> See the list of Known Issues and TODOs, below, for updates.


## Overview

Behold Ihsan Project


## Installation

```shell script
poetry add ihsan

```

or

```shell script
pip install ihsan

```
